import requests

global devicecode
global authstatus
global requestid


def initialize_auth():
    global devicecode
    global requestid
    auth_url = "https://onlineservices.adriandevprojects.com/v1/auth/devicelogin/new/"


    headers = {
        "Content-Type": "application/x-www-form-urlencoded"
    }

    response = requests.post(auth_url, headers=headers)
    data = response.json()
    requestid = data['requestid']
    devicecode = data['devicecode']





def check_auth(requestid):
    global authstatus
    global devicecode
    auth_url = "https://onlineservices.adriandevprojects.com/v1/auth/devicelogin/check/"

    headers = {
        "Content-Type": "application/x-www-form-urlencoded"
    }

    rid = {
        "requestid": requestid
    }

    success = False

    while success is False:
        response = requests.post(auth_url, headers=headers, data=rid)
        data = response.json()
        status = data['status']
        if status == "SUCCESS":
            userid = data['userid']
            with open("userdata.txt", "w+") as accfile:
                accfile.write(userid)
                success = True
                authstatus = "SUCCESS"
                break

        elif status == "WAITING":
            authstatus = "WAITING"
            continue

        else:
            authstatus ="FAILED"
            break

    return authstatus


def get_auth_status():
    global authstatus
    return authstatus

def get_device_code():
    global devicecode
    return devicecode

def get_request_id():
    global requestid
    return requestid


import webbrowser
from pathlib2 import Path

def info():
    print("Playdion ClientKit v2025.5.8rc1")



def checklogin():
    accfile = Path("userdata.txt")
    if accfile.is_file():
        with open("userdata.txt", "r") as accfile:
            userid = accfile.read()
            if userid is not None or "":
                return True
            else:
                return False
    else:
        return False


def getuserid():
    state = checklogin()
    if state is True:
        with open("userdata.txt", "r") as accfile:
            userid = accfile.read()
            return userid
    else:
        return False


def open_auth_url():
    auth_url = "https://onlineservices.adriandevprojects.com/v1/auth/devicelogin/"
    webbrowser.open_new(auth_url)


import ClientKit
import requests
import os


def login(username, password):
    login_url = "https://onlineservices.adriandevprojects.com/v1/auth/login/"

    credentials = {
        "username": username,
        "password": password
    }

    headers = {
        "Content-Type": "application/x-www-form-urlencoded"
    }
    logincheck = ClientKit.checklogin()
    if logincheck is False:
        response = requests.post(login_url, data=credentials, headers=headers)
        if response.status_code == 200:
            with open("userdata.txt", "w+") as accfile:
                accfile.write(response.text)
                return True
        else:
            return f"Login failed: {response.text}"
    else:
        return "User already logged in"


def register(username, password, instant_login=bool):
    register_url = "https://onlineservices.adriandevprojects.com/v1/auth/register/"

    register_credentials = {
        "username": username,
        "password": password,
        "confirm_password": password
    }

    register_headers = {
        "Content-Type": "application/x-www-form-urlencoded"
    }

    response = requests.post(register_url, data=register_credentials, headers=register_headers)

    if response.status_code == 201:
        if instant_login:
            return login(username, password)
        else:
            return True
    else:
        return f"Registration failed: {response.text}"


def logout():
    state = ClientKit.checklogin()
    if state is True:
        os.remove("userdata.txt")
        return True
    else:
        return False



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="PlaydionClientKit",
    version="2025.5.8rc1",
    author="Adrian Albrecht",
    author_email="adriandevprojects@gmail.com",
    packages=setuptools.find_packages(),
    url="https://github.com/AdrianDevProjects/ClientKit",
    license="GPL-3.0",
    description="ClientKit for Playdion Client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        "requests",
        "pathlib2",
    ]
)
